@@ -25,11 +25,12 @@ class Cube(Spectrum):
     pass
 
 
-@sdss_loader(name='mangacube', defaults={'wave': 'LOG'}, mapped_version='manga:drpver',
+@sdss_loader(name='mangacube', defaults={'wave': 'LOG'}, mapped_version='drpver',
              pattern=r'(?P<plateifu>(?P<plate>\d{4,5})-(?P<ifu>\d{3,5}))|(?P<mangaid>\d{1,2}-\d{4,9})')
 class MangaCube(Spectrum):
     """ Class representing a MaNGA IFU datacube for a single galaxy """
     specutils_format: str = 'MaNGA cube'
+    datamodel: str = 'mangaCube'
     _api = ('marvin', 'cubes/{plateifu}/')
 
     def _load_object_from_db(self):
